otBorderAgentEphemeralKeyGenerateTap

Function otBorderAgentEphemeralKeyGenerateTap 

pub unsafe extern "C" fn otBorderAgentEphemeralKeyGenerateTap(
    aTap: *mut otBorderAgentEphemeralKeyTap,
) -> otError
Generates a cryptographically secure random Thread Administration One-Time Passcode (TAP) string.

Requires OPENTHREAD_CONFIG_BORDER_AGENT_EPHEMERAL_KEY_ENABLE and OPENTHREAD_CONFIG_VERHOEFF_CHECKSUM_ENABLE.

The TAP is a string of 9 characters, generated as a sequence of eight cryptographically secure random numeric digits [0-9] followed by a single check digit determined using the Verhoeff algorithm.

@param[out] aTap A pointer to an otBorderAgentEphemeralKeyTap to output the generated TAP.

@retval OT_ERROR_NONE Successfully generated a random TAP. @p aTap is updated. @retval OT_ERROR_FAILED Failed to generate a random TAP.