otBorderRoutingInit

Function otBorderRoutingInit 

pub unsafe extern "C" fn otBorderRoutingInit(
    aInstance: *mut otInstance,
    aInfraIfIndex: u32,
    aInfraIfIsRunning: bool,
) -> otError
Initializes the Border Routing Manager on given infrastructure interface.

This function MUST be called before any other otBorderRouting* APIs.

This function can also be used to re-initialize and switch the infrastructure interface index to a new one. Switching the interface index will trigger all components running on the previous interface (Border Routing, mDNS, etc) to be stopped (as if the previous if-index is no longer running) before restarting operations on the new interface.

@param[in] aInstance A pointer to an OpenThread instance. @param[in] aInfraIfIndex The infrastructure interface index. @param[in] aInfraIfIsRunning A boolean that indicates whether the infrastructure

@retval OT_ERROR_NONE Successfully started the Border Routing Manager on given infrastructure.

@sa otPlatInfraIfStateChanged. @sa otBorderRoutingSetEnabled.