otCliOutputBytes

Function otCliOutputBytes 

pub unsafe extern "C" fn otCliOutputBytes(
    aBytes: *const u8,
    aLength: u8,
)
Write a number of bytes to the static CLI interpreter output as a hex string.

Requires OPENTHREAD_CONFIG_CLI_STATIC_INTERPRETER_ENABLE.

This is intended for use by user-provided CLI command handlers.

@param[in] aBytes A pointer to data which should be printed. @param[in] aLength @p aBytes length.