otDatasetIsValid

Function otDatasetIsValid 

pub unsafe extern "C" fn otDatasetIsValid(
    aDatasetTlvs: *const otOperationalDatasetTlvs,
    aActive: bool,
) -> bool
Indicates whether or not the given Operational Dataset TLVs is a valid Active or Pending Dataset.

A valid Active Dataset MUST contain all the required TLVs (Active Timestamp, Channel, Channel Mask, Extended PAN ID, Mesh-Local Prefix, Network Key, Network Name, PAN ID, PSKc, and Security Policy).

A valid Pending Dataset MUST contain all the required TLVs for an Active Dataset and additionally MUST contain Pending Timestamp and Delay Timer TLVs.

This method also checks whether there are duplicated TLVs or the TLVs are not well-formed in the @p aDatasetTlvs.

@param[in] aDatasetTlvs A pointer to dataset TLVs. @param[in] aActive TRUE for Active Dataset, FALSE for Pending Dataset.

@returns TRUE if @p aDatasetTlvs is a valid Dataset, FALSE otherwise.