otDatasetTlvsCompare

Function otDatasetTlvsCompare 

pub unsafe extern "C" fn otDatasetTlvsCompare(
    aDatasetTlvsA: *const otOperationalDatasetTlvs,
    aDatasetTlvsB: *const otOperationalDatasetTlvs,
) -> bool
Compares two Operational Dataset TLVs to determine if they contain the same set of TLVs.

This function performs a deep comparison. It parses both @p aDatasetTlvsA and @p aDatasetTlvsB and checks if they contain the exact same set of TLVs (same type and same value). The order of TLVs within the otOperationalDatasetTlvs does not matter.

@param[in] aDatasetTlvsA A pointer to dataset TLVs A. Must not be NULL. @param[in] aDatasetTlvsB A pointer to dataset TLVs B. Must not be NULL.

@returns TRUE if the two Operational Dataset TLVs match, FALSE otherwise (e.g., if any TLV differs, is missing, or if the TLVs are not well-formed).