otHistoryTrackerIterateBorderAgentEpskcEventHistory

Function otHistoryTrackerIterateBorderAgentEpskcEventHistory 

pub unsafe extern "C" fn otHistoryTrackerIterateBorderAgentEpskcEventHistory(
    aInstance: *mut otInstance,
    aIterator: *mut otHistoryTrackerIterator,
    aEntryAge: *mut u32,
) -> *const otHistoryTrackerBorderAgentEpskcEvent
Iterates over the entries in the Border Agent ePSKc history list.

@param[in] aInstance A pointer to the OpenThread instance. @param[in,out] aIterator A pointer to an iterator. MUST be initialized or the behavior is undefined. @param[out] aEntryAge A pointer to a variable to output the entry’s age. MUST NOT be NULL. Age is provided as the duration (in milliseconds) from when entry was recorded to @p aIterator initialization time. It is set to OT_HISTORY_TRACKER_MAX_AGE for entries older than max age.

@returns The otHistoryTrackerBorderAgentEpskcEvent entry or NULL if no more entries in the list.