pub unsafe extern "C" fn otIp6SetEnabled(
aInstance: *mut otInstance,
aEnabled: bool,
) -> otErrorExpand description
Brings the IPv6 interface up or down.
Call this to enable or disable IPv6 communication.
When OPENTHREAD_CONFIG_IP6_INIT_EXT_ADDR_POOL_ENABLE is enabled, otIp6Init() MUST be called prior to calling
this function. If it is not, this function will return OT_ERROR_INVALID_STATE.
@param[in] aInstance A pointer to an OpenThread instance. @param[in] aEnabled TRUE to enable IPv6, FALSE otherwise.
@retval OT_ERROR_NONE Successfully brought the IPv6 interface up/down.
@retval OT_ERROR_INVALID_STATE IPv6 interface is not available since device is operating in raw-link mode
(applicable only when OPENTHREAD_CONFIG_LINK_RAW_ENABLE feature is enabled),
or not initialized under OPENTHREAD_CONFIG_IP6_INIT_EXT_ADDR_POOL_ENABLE.