otLoggingGetLevel

Function otLoggingGetLevel 

pub unsafe extern "C" fn otLoggingGetLevel() -> otLogLevel
Returns the current global log level.

In a single-instance configuration, this function behaves the same as otGetLogLevel(). In a multi-instance configuration, it returns the global log level which is used for all instances.

@returns The global log level.