[][src]Function openthread_sys::otMessageQueueGetHead

pub unsafe extern "C" fn otMessageQueueGetHead(
    aQueue: *mut otMessageQueue
) -> *mut otMessage

This function returns a pointer to the message at the head of the queue.

@param[in] aQueue A pointer to a message queue.

@returns A pointer to the message at the head of queue or NULL if queue is empty.