Function otNcpHandleLegacyNodeDidJoin

pub unsafe extern "C" fn otNcpHandleLegacyNodeDidJoin(
    aExtAddr: *const otExtAddress,
)
This callback is invoked by the legacy stack to notify that a new legacy node did join the network.

@param[in] aExtAddr A pointer to the extended address of the joined node.