pub unsafe extern "C" fn otPlatAssertFail(
aFilename: *const c_char,
aLineNumber: c_int,
)Expand description
This function provides a platform specific implementation for assert.
@param[in] aFilename The name of the file where the assert occurred. @param[in] aLineNumber The line number in the file where the assert occurred.