otPlatCryptoCAlloc

Function otPlatCryptoCAlloc 

pub unsafe extern "C" fn otPlatCryptoCAlloc(
    aNum: usize,
    aSize: usize,
) -> *mut c_void
Dynamically allocates new memory for the Crypto subsystem. On platforms that support it, they should redirect to calloc. For those that don’t support calloc, they should implement the standard calloc behavior.

See: https://man7.org/linux/man-pages/man3/calloc.3.html

Is required for OPENTHREAD_CONFIG_HEAP_EXTERNAL_ENABLE.

@param[in] aNum The number of blocks to allocate @param[in] aSize The size of each block to allocate

@retval void* The pointer to the front of the memory allocated @retval NULL Failed to allocate the memory requested.