otPlatInfraIfDiscoverNat64Prefix

Function otPlatInfraIfDiscoverNat64Prefix 

pub unsafe extern "C" fn otPlatInfraIfDiscoverNat64Prefix(
    aInstance: *mut otInstance,
    aInfraIfIndex: u32,
) -> otError
Send a request to discover the NAT64 prefix on the infrastructure interface with @p aInfraIfIndex.

OpenThread will call this method periodically to monitor the presence or change of NAT64 prefix.

@param[in] aInstance The OpenThread instance. @param[in] aInfraIfIndex The index of the infrastructure interface to discover the NAT64 prefix.

@retval OT_ERROR_NONE Successfully requested NAT64 prefix discovery. @retval OT_ERROR_FAILED Failed to request NAT64 prefix discovery. @retval OT_ERROR_NOT_IMPLEMENTED Platform does not support this discovery method. will rely on RA-based mechanism.

@note This function requests the platform to discover a NAT64 prefix (e.g. using RFC 7050 DNS-based discovery). The priority of the discovered prefix is lower than that of the prefix discovered via Router Advertisements PREF64 option (RFC 8781).