otPlatLog

Function otPlatLog 

pub unsafe extern "C" fn otPlatLog(
    aLogLevel: otLogLevel,
    aLogRegion: otLogRegion,
    aFormat: *const c_char,
    ...
)
Outputs logs.

This platform API is used to output logs when the configuration OPENTHREAD_CONFIG_LOG_INSTANCE_AWARE_API_ENABLE is disabled. When the configuration is enabled, otPlatLogOutput() is used instead.

Note that the support for log region is removed. The OT core will always emit all logs with OT_LOG_REGION_CORE as @p aLogRegion.

@param[in] aLogLevel The log level. @param[in] aLogRegion The log region. @param[in] aFormat A pointer to the format string. @param[in] … Arguments for the format specification.