Function otPlatMessagePoolInit

pub unsafe extern "C" fn otPlatMessagePoolInit(
    aInstance: *mut otInstance,
    aMinNumFreeBuffers: u16,
    aBufferSize: size_t,
)
Initialize the platform implemented message pool.

@param[in] aInstance A pointer to the OpenThread instance. @param[in] aMinNumFreeBuffers An uint16 containing the minimum number of free buffers desired by OpenThread. @param[in] aBufferSize The size in bytes of a Buffer object.