pub unsafe extern "C" fn otPlatSettingsInit(
aInstance: *mut otInstance,
)Expand description
Performs any initialization for the settings subsystem, if necessary.
@param[in] aInstance The OpenThread instance structure.
pub unsafe extern "C" fn otPlatSettingsInit(
aInstance: *mut otInstance,
)Performs any initialization for the settings subsystem, if necessary.
@param[in] aInstance The OpenThread instance structure.