otThreadIsRouterEligible

Function otThreadIsRouterEligible 

pub unsafe extern "C" fn otThreadIsRouterEligible(
    aInstance: *mut otInstance,
) -> bool
Indicates whether or not the device is allowed to take router or leader roles.

A device is allowed to become a router if it is a Full Thread Device (FTD), is currently configured to be router-eligible (see otThreadSetRouterEligible(true)), and the active Security Policy permits routers.

@param[in] aInstance A pointer to an OpenThread instance.

@retval TRUE If the router role is allowed. @retval FALSE If the router role is not allowed.