pub unsafe extern "C" fn otThreadRegisterNeighborTableCallback(
aInstance: *mut otInstance,
aCallback: otNeighborTableCallback,
)Expand description
This function registers a neighbor table callback function.
The provided callback (if non-NULL) will be invoked when a child or router neighbor entry is being added/removed
to/from the neighbor table. Subsequent calls to this method will overwrite the previous callback. Note that this
callback in invoked while the neighbor/child table is being updated and always before the otStateChangedCallback.
@param[in] aInstance A pointer to an OpenThread instance. @param[in] aCallback A pointer to callback handler function.