Function otThreadSetReceiveDiagnosticGetCallback

pub unsafe extern "C" fn otThreadSetReceiveDiagnosticGetCallback(
    aInstance: *mut otInstance,
    aCallback: otReceiveDiagnosticGetCallback,
    aCallbackContext: *mut c_void,
)
This function registers a callback to provide received raw Network Diagnostic Get response payload.

@param[in] aInstance A pointer to an OpenThread instance. @param[in] aCallback A pointer to a function that is called when Network Diagnostic Get response is received or NULL to disable the callback. @param[in] aCallbackContext A pointer to application-specific context.