otThreadVendorOuiToString

Function otThreadVendorOuiToString 

pub unsafe extern "C" fn otThreadVendorOuiToString(
    aOui: *const otThreadVendorOui,
    aBuffer: *mut c_char,
    aSize: u16,
)
Converts a given vendor OUI to a human-readable string.

The generated string format is hyphen-separated uppercase hexadecimal bytes (e.g., “00-1A-2B” for a 24-bit OUI). For 28-bit and 36-bit OUIs, the trailing 4-bit nibble is appended as a single hexadecimal digit (e.g., “00-1A-2B-3” for a 28-bit OUI). If @p aOui is invalid or unspecified, the string “unspecified” is returned.

If the resulting string does not fit in @p aBuffer (within its @p aSize characters), the string will be truncated but the outputted string is always null-terminated.

@param[in] aOui The vendor OUI to convert. @param[out] aBuffer A pointer to a char array to output the string (MUST NOT be NULL). @param[in] aSize The size of @p aBuffer (in bytes). Recommended to use OT_THREAD_VENDOR_OUI_STRING_SIZE.