#[repr(C)]pub struct otCoapTxParameters {
pub mAckTimeout: u32,
pub mAckRandomFactorNumerator: u8,
pub mAckRandomFactorDenominator: u8,
pub mMaxRetransmit: u8,
}Expand description
This structure represents the CoAP transmission parameters.
Fields
mAckTimeout: u32Minimum spacing before first retransmission when ACK is not received, in milliseconds (RFC7252 default value is 2000ms).
mAckRandomFactorNumerator: u8Numerator of ACK_RANDOM_FACTOR used to calculate maximum spacing before first retransmission when ACK is not received (RFC7252 default value of ACK_RANDOM_FACTOR is 1.5; must not be decreased below 1).
mAckRandomFactorDenominator: u8Denominator of ACK_RANDOM_FACTOR used to calculate maximum spacing before first retransmission when ACK is not received (RFC7252 default value of ACK_RANDOM_FACTOR is 1.5; must not be decreased below 1).
mMaxRetransmit: u8Maximum number of retransmissions for CoAP Confirmable messages (RFC7252 default value is 4).