#[repr(C)]pub struct otDnsQuery {
pub mHostname: *const c_char,
pub mMessageInfo: *const otMessageInfo,
pub mNoRecursion: bool,
}Expand description
This structure implements DNS Query parameters.
Fields
mHostname: *const c_char< Identifies hostname to be found. It shall not change during resolving.
mMessageInfo: *const otMessageInfo< A reference to the message info related with DNS Server.
mNoRecursion: bool< If cleared, it directs name server to pursue the query recursively.