#[repr(C)]pub struct otDnsTxtEntryIterator {
pub mPtr: *const c_void,
pub mData: [u16; 2],
pub mChar: [c_char; 65],
}Expand description
Represents an iterator for TXT record entries (key/value pairs).
The data fields in this structure are intended for use by OpenThread core and caller should not read or change them.
Fields
mPtr: *const c_voidmData: [u16; 2]mChar: [c_char; 65]Trait Implementations
Sourceimpl Clone for otDnsTxtEntryIterator
impl Clone for otDnsTxtEntryIterator
Sourcefn clone(&self) -> otDnsTxtEntryIterator
fn clone(&self) -> otDnsTxtEntryIterator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for otDnsTxtEntryIterator
Sourceimpl Debug for otDnsTxtEntryIterator
impl Debug for otDnsTxtEntryIterator