#[repr(C)]pub struct otHistoryTrackerDnsSrpAddrInfo {
pub mAddress: otIp6Address,
pub mRloc16: u16,
pub mPort: u16,
pub mSequenceNumber: u8,
pub mVersion: u8,
pub mType: otHistoryTrackerDnsSrpAddrType,
pub mEvent: otHistoryTrackerNetDataEvent,
}Expand description
Represents DNS/SRP server address information parsed from a Network Data service entry.
The mType field specifies the entry type. Some fields are only applicable to specific types.
- The
mPortfield is only applicable forOT_HISTORY_TRACKER_DNS_SRP_ADDR_TYPE_UNICAST_*types. - The
mSequenceNumberfield is only applicable for theOT_HISTORY_TRACKER_DNS_SRP_ADDR_TYPE_ANYCASTtype. - Other fields are common and used for all address types.
Fields
mAddress: otIp6Address< The server address.
mRloc16: u16< The RLOC16 of the Border Router adding/removing the entry.
mPort: u16< Port number.
mSequenceNumber: u8< Anycast sequence number.
mVersion: u8< Version number.
mType: otHistoryTrackerDnsSrpAddrType< Address type.
mEvent: otHistoryTrackerNetDataEvent< Indicates the event (added/removed).