otHistoryTrackerFavoredOmrPrefix

Struct otHistoryTrackerFavoredOmrPrefix 

#[repr(C, align(4))]
pub struct otHistoryTrackerFavoredOmrPrefix { pub mOmrPrefix: otIp6Prefix, pub _bitfield_align_1: [u8; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>, pub __bindgen_padding_0: u16, }
Represents a favored OMR prefix tracked by a device acting as a Border Router (BR).

The mIsLocal field indicates whether the favored OMR prefix is the same as the local one maintained by this BR. The local OMR prefix can be either based on (random) ULA or a prefix delegated via DHCPv6-PD.

Fields

mOmrPrefix: otIp6Prefix

< The OMR prefix.

_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>__bindgen_padding_0: u16

Implementations

Source

impl otHistoryTrackerFavoredOmrPrefix

pub fn mPreference(&self) -> c_int

pub fn set_mPreference(&mut self, val: c_int)

pub unsafe fn mPreference_raw(this: *const Self) -> c_int

pub unsafe fn set_mPreference_raw(this: *mut Self, val: c_int)

pub fn mIsLocal(&self) -> bool

pub fn set_mIsLocal(&mut self, val: bool)

pub unsafe fn mIsLocal_raw(this: *const Self) -> bool

pub unsafe fn set_mIsLocal_raw(this: *mut Self, val: bool)

pub fn new_bitfield_1( mPreference: c_int, mIsLocal: bool, ) -> __BindgenBitfieldUnit<[u8; 1]>