#[repr(C)]pub struct otHistoryTrackerFavoredOnLinkPrefix {
pub mOnLinkPrefix: otIp6Prefix,
pub _bitfield_align_1: [u8; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>,
}Expand description
Represents a favored on-link prefix on AIL tracked by a device acting as a Border Router (BR).
The mIsLocal field indicates whether the favored on-link prefix is the same as the local one maintained by this
BR.
Fields
mOnLinkPrefix: otIp6Prefix< The on-link prefix.
_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>Implementations
Sourceimpl otHistoryTrackerFavoredOnLinkPrefix
impl otHistoryTrackerFavoredOnLinkPrefix
pub fn mIsLocal(&self) -> bool
pub fn set_mIsLocal(&mut self, val: bool)
pub unsafe fn mIsLocal_raw(this: *const Self) -> bool
pub unsafe fn set_mIsLocal_raw(this: *mut Self, val: bool)
pub fn new_bitfield_1(mIsLocal: bool) -> __BindgenBitfieldUnit<[u8; 1]>