#[repr(C)]pub struct otLinkedBuffer {
pub mNext: *mut otLinkedBuffer,
pub mData: *const u8,
pub mLength: usize,
}Expand description
A linked buffer structure for use with TCP.
A single otLinkedBuffer structure references an array of bytes in memory, via mData and mLength. The mNext field is used to form a chain of otLinkedBuffer structures.
Fields
mNext: *mut otLinkedBuffer< Pointer to the next linked buffer in the chain, or NULL if it is the end.
mData: *const u8< Pointer to data referenced by this linked buffer.
mLength: usize< Length of this linked buffer (number of bytes).