#[repr(C)]pub struct otNetworkDiagConnectivity {
pub mParentPriority: i8,
pub mLinkQuality3: u8,
pub mLinkQuality2: u8,
pub mLinkQuality1: u8,
pub mLeaderCost: u8,
pub mIdSequence: u8,
pub mActiveRouters: u8,
pub mSedBufferSize: u16,
pub mSedDatagramCount: u8,
}Expand description
This structure represents a Network Diagnostic Connectivity value.
Fields
mParentPriority: i8The priority of the sender as a parent.
mLinkQuality3: u8The number of neighboring devices with which the sender shares a link of quality 3.
mLinkQuality2: u8The number of neighboring devices with which the sender shares a link of quality 2.
mLinkQuality1: u8The number of neighboring devices with which the sender shares a link of quality 1.
mLeaderCost: u8The sender’s routing cost to the Leader.
mIdSequence: u8The most recent ID sequence number received by the sender.
mActiveRouters: u8The number of active Routers in the sender’s Thread Network Partition.
mSedBufferSize: u16The guaranteed buffer capacity in octets for all IPv6 datagrams destined to a given SED. Optional.
mSedDatagramCount: u8The guaranteed queue capacity in number of IPv6 datagrams destined to a given SED. Optional.