#[repr(C)]pub struct otOperationalDataset {Show 13 fields
pub mActiveTimestamp: u64,
pub mPendingTimestamp: u64,
pub mMasterKey: otMasterKey,
pub mNetworkName: otNetworkName,
pub mExtendedPanId: otExtendedPanId,
pub mMeshLocalPrefix: otMeshLocalPrefix,
pub mDelay: u32,
pub mPanId: otPanId,
pub mChannel: u16,
pub mPskc: otPskc,
pub mSecurityPolicy: otSecurityPolicy,
pub mChannelMask: otChannelMask,
pub mComponents: otOperationalDatasetComponents,
}Expand description
This structure represents an Active or Pending Operational Dataset.
Components in Dataset are optional. mComponets structure specifies which components are present in the Dataset.
Fields
mActiveTimestamp: u64< Active Timestamp
mPendingTimestamp: u64< Pending Timestamp
mMasterKey: otMasterKey< Network Master Key
mNetworkName: otNetworkName< Network Name
mExtendedPanId: otExtendedPanId< Extended PAN ID
mMeshLocalPrefix: otMeshLocalPrefix< Mesh Local Prefix
mDelay: u32< Delay Timer
mPanId: otPanId< PAN ID
mChannel: u16< Channel
mPskc: otPskc< PSKc
mSecurityPolicy: otSecurityPolicy< Security Policy
mChannelMask: otChannelMask< Channel Mask
mComponents: otOperationalDatasetComponents< Specifies which components are set in the Dataset.