[−][src]Struct openthread_sys::otPlatBleGattService
Registration descriptor for a GATT service.
Fields
mUuid: otPlatBleUuidPointer to service UUID; use BLE_UUIDxx_DECLARE macros to declare proper UUID; NULL if there are no more characteristics in the service.
mHandle: u16Handle of service; written to by stack after call to otPlatBleGattServerServicesRegister.
mCharacteristics: *mut otPlatBleGattCharacteristicArray of characteristic definitions corresponding to characteristics belonging to this service.