otThreadVendorOui

Struct otThreadVendorOui 

#[repr(C)]
pub struct otThreadVendorOui { pub mBitLength: u8, pub mBytes: [u8; 5], }
Represents a Thread Vendor OUI (Organizationally Unique Identifier) which can have different lengths.

A Vendor OUI can be assigned in one of the following formats:

  • 24-bit Prefix (MA-L): Exactly 3 bytes (24 bits). Example: 00-1A-2B is represented with mBitLength = 24 and mBytes = [0x00, 0x1A, 0x2B, 0x00, 0x00].

  • 28-bit Prefix (MA-M): Exactly 3.5 bytes (28 bits). The half-byte (4 bits) at the end of the prefix occupies the Most Significant Nibble of the 4th byte. The Least Significant Nibble of the 4th byte is set to zero. Example: 00-1A-2B-3 is represented with mBitLength = 28 and mBytes = [0x00, 0x1A, 0x2B, 0x30, 0x00].

  • 36-bit Prefix (MA-S): Exactly 4.5 bytes (36 bits). The half-byte (4 bits) at the end of the prefix occupies the Most Significant Nibble of the 5th byte. The Least Significant Nibble of the 5th byte is set to zero. Example: 00-1A-2B-3C-4 is represented with mBitLength = 36 and mBytes = [0x00, 0x1A, 0x2B, 0x3C, 0x40].

Fields

mBitLength: u8

< The OUI prefix length in bits (24, 28, or 36).

mBytes: [u8; 5]

< The OUI bytes in big-endian order.