otHistoryTrackerAilRouterEvent

Type Alias otHistoryTrackerAilRouterEvent 

pub type otHistoryTrackerAilRouterEvent = c_uint;
Defines events for discovered routers on an Adjacent Infrastructure Link (AIL).

This applies when a device is acting as a Border Router, processing received Router Advertisements and tracking AIL routers.

OT_HISTORY_TRACKER_AIL_ROUTER_EVENT_CHANGED is used if any of the properties in the otHistoryTrackerAilRouter structure associated with a specific router changes.