otHistoryTrackerNeighborEvent

Type Alias otHistoryTrackerNeighborEvent 

pub type otHistoryTrackerNeighborEvent = c_uint;
Defines the events in a neighbor info (i.e. whether neighbor is added, removed, or changed).

Event OT_HISTORY_TRACKER_NEIGHBOR_EVENT_RESTORING is applicable to child neighbors only. It is triggered after the device (re)starts and when the previous children list is retrieved from non-volatile settings and the device tries to restore connection to them.