[−][src]Type Definition openthread_sys::otLinkRawReceiveDone
type otLinkRawReceiveDone = Option<unsafe extern "C" fn(aInstance: *mut otInstance, aFrame: *mut otRadioFrame, aError: otError)>;
This function pointer on receipt of a IEEE 802.15.4 frame.
@param[in] aInstance A pointer to an OpenThread instance. @param[in] aFrame A pointer to the received frame or NULL if the receive operation was aborted. @param[in] aError OT_ERROR_NONE when successfully received a frame. OT_ERROR_ABORT when reception was aborted and a frame was not received.