pub type otNcpHandlerJoinLegacyNode = Option<unsafe extern "C" fn(aExtAddress: *const otExtAddress)>;Expand description
Defines handler (function pointer) type for initiating joining process.
@param[in] aExtAddress A pointer to the extended address for the node to join or NULL if desired to join any neighboring node.
Invoked to initiate a legacy join procedure to any or a specific node.
Aliased Type
enum otNcpHandlerJoinLegacyNode {
None,
Some(unsafe extern "C" fn(_: *const otExtAddress)),
}