pub type otNeighborTableCallback = Option<unsafe extern "C" fn(aEvent: otNeighborTableEvent, aEntryInfo: *const otNeighborTableEntryInfo)>;Expand description
This function pointer is called to notify that a child or router neighbor is being added to or removed from neighbor table.
@param[in] aEvent A event flag. @param[in] aEntryInfo A pointer to table entry info.
Aliased Type
enum otNeighborTableCallback {
None,
Some(unsafe extern "C" fn(_: u32, _: *const otNeighborTableEntryInfo)),
}