pub type otThreadParentResponseCallback = Option<unsafe extern "C" fn(aInfo: *mut otThreadParentResponseInfo, aContext: *mut c_void)>;Expand description
This function pointer is called every time an MLE Parent Response message is received.
@param[in] aStats pointer to a location on stack holding the stats data. @param[in] aContext A pointer to callback client-specific context.
Aliased Type
enum otThreadParentResponseCallback {
None,
Some(unsafe extern "C" fn(_: *mut otThreadParentResponseInfo, _: *mut c_void)),
}