otUdpHandler

Type Alias otUdpHandler 

pub type otUdpHandler = Option<unsafe extern "C" fn(aContext: *mut c_void, aMessage: *const otMessage, aMessageInfo: *const otMessageInfo) -> bool>;
Represents a callback to handle a received UDP message.

This callback is used by a UDP receiver (see otUdpAddReceiver()) to process an incoming UDP message.

This callback does not transfer ownership of @p aMessage. The callback implementation must not modify the message content. The message is guaranteed to be valid only within the context of the callback.

@param[in] aContext A pointer to the application-specific context. @param[in] aMessage A pointer to the received UDP message. @param[in] aMessageInfo A pointer to the IPv6 message info structure.

@retval TRUE The message is handled by this receiver and should not be further processed. @retval FALSE The message is not handled by this receiver.

Aliased Type

pub enum otUdpHandler {
    None,
    Some(unsafe extern "C" fn(*mut c_void, *const otMessage, *const otMessageInfo) -> bool),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut c_void, *const otMessage, *const otMessageInfo) -> bool)

Some value of type T.