pub unsafe extern "C" fn otBorderAgentEphemeralKeyValidateTap(
aTap: *const otBorderAgentEphemeralKeyTap,
) -> otErrorExpand description
Validates a given Thread Administration One-Time Passcode (TAP) string.
Requires OPENTHREAD_CONFIG_BORDER_AGENT_EPHEMERAL_KEY_ENABLE and OPENTHREAD_CONFIG_VERHOEFF_CHECKSUM_ENABLE.
Validates that the TAP string has the proper length, contains digit characters [0-9], and validates the
Verhoeff checksum.
@param[in] aTap The otBorderAgentEphemeralKeyTap to validate.
@retval OT_ERROR_NONE Successfully validated the @p aTap. @retval OT_ERROR_INVALID_ARGS The @p aTap string has an invalid length or contains non-digit characters. @retval OT_ERROR_FAILED Checksum validation failed.