pub unsafe extern "C" fn otCliSetUserCommands(
aUserCommands: *const otCliCommand,
aLength: u8,
aContext: *mut c_void,
) -> otErrorExpand description
Set a user command table on the static CLI interpreter.
Requires OPENTHREAD_CONFIG_CLI_STATIC_INTERPRETER_ENABLE.
@param[in] aUserCommands A pointer to an array with user commands. @param[in] aLength The @p aUserCommands length. @param[in] aContext The context passed to the handler.
@retval OT_ERROR_NONE Successfully updated command table with commands from @p aUserCommands. @retval OT_ERROR_NO_BUFS Maximum number of command entries have already been set.