pub unsafe extern "C" fn otDatasetAffectsConnectivity(
aInstance: *mut otInstance,
aDatasetTlvs: *const otOperationalDatasetTlvs,
) -> boolExpand description
Indicates whether or not a given Operational Dataset (in TLVs format) affects connectivity.
A Dataset affects connectivity if it contains a different Channel, PAN ID, Mesh Local Prefix, Network Key, or Security Policy than the current values in use.
The following security policy changes are considered to affect connectivity:
- Disabling routers (R bit: 1 to 0).
- Enabling non-CCM routers (NCR bit: 0 to 1).
- Increasing the version threshold for routing (VR field).
@param[in] aInstance A pointer to an OpenThread instance. @param[in] aDatasetTlvs A pointer to Operational Dataset TLVs.
@returns TRUE if @p aDatasetTlvs affects connectivity, FALSE otherwise.