pub unsafe extern "C" fn otLoggingSetLevel(
aLogLevel: otLogLevel,
) -> otErrorExpand description
Sets the global log level.
@note This function requires OPENTHREAD_CONFIG_LOG_LEVEL_DYNAMIC_ENABLE=1.
In a single-instance configuration, this function behaves the same as otSetLogLevel() (which is the recommended
function to use).
In a multi-instance configuration, it sets the global log level which is used by all instances. The log level can
be explicitly set on a specific instance using otSetLogLevel(), which will then be used instead of the global
value.
@param[in] aLogLevel The log level.
@retval OT_ERROR_NONE Successfully updated the log level. @retval OT_ERROR_INVALID_ARGS Log level value is invalid.