pub unsafe extern "C" fn otPlatLogHandleLevelChanged(
aLogLevel: otLogLevel,
)Expand description
Handles OpenThread log level changes.
This platform function is optional. An empty weak implementation is provided by OpenThread core.
This platform function is called whenever the OpenThread log level changes:
- In a single-instance configuration, this is called when the log level changes.
- In a multi-instance configuration, this is called when the global log level changes.
@note Only applicable when OPENTHREAD_CONFIG_LOG_LEVEL_DYNAMIC_ENABLE=1.
@param[in] aLogLevel The new OpenThread log level.