#[repr(C)]pub struct otBorderRoutingNat64PrefixEntry {
pub mRouter: otBorderRoutingRouterEntry,
pub mPrefix: otIp6Prefix,
pub mMsecSinceLastUpdate: u32,
pub mLifetime: u32,
}Expand description
Represents an entry from the discovered NAT64 prefix table.
The entries in the discovered table track the NAT64 Prefix Options in the received Router Advertisement messages from other routers on the infrastructure link.
Fields
mRouter: otBorderRoutingRouterEntry< Information about the router advertising this NAT64 prefix.
mPrefix: otIp6Prefix< The discovered IPv6 prefix.
mMsecSinceLastUpdate: u32< Milliseconds since last update of this prefix.
mLifetime: u32< Lifetime of the prefix (in seconds).