[−][src]Struct openthread_sys::otDnsQuery
This structure implements DNS Query parameters.
Fields
mHostname: *const c_char< Identifies hostname to be found. It shall not change during resolving.
mMessageInfo: *const otMessageInfo< A reference to the message info related with DNS Server.
mNoRecursion: bool< If cleared, it directs name server to pursue the query recursively.