#[repr(C)]pub struct otHistoryTrackerAilRouter {
pub mEvent: otHistoryTrackerAilRouterEvent,
pub mDefRoutePreference: i8,
pub mAddress: otIp6Address,
pub mFavoredOnLinkPrefix: otIp6Prefix,
pub _bitfield_align_1: [u8; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>,
pub __bindgen_padding_0: u8,
}Expand description
Represents information about a discovered router on an Adjacent Infrastructure Link (AIL).
This applies when a device is acting as a Border Router, processing received Router Advertisements and tracking information about discovered AIL routers.
mProvidesDefaultRoute indicates whether the router provides a default route. If it does, mDefRoutePreference
specifies the route preference.
mFavoredOnLinkPrefix indicates the favored on-link prefix advertised by the router. If there is no on-link prefix,
this will be an empty prefix (i.e., its length will be zero).
Fields
mEvent: otHistoryTrackerAilRouterEvent< The event type (e.g., added, changed, removed).
mDefRoutePreference: i8< Def route preference.
mAddress: otIp6Address< The IPv6 address of the AIL router.
mFavoredOnLinkPrefix: otIp6Prefix< The favored on-link prefix, if any.
_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>__bindgen_padding_0: u8Implementations
Sourceimpl otHistoryTrackerAilRouter
impl otHistoryTrackerAilRouter
pub fn mProvidesDefaultRoute(&self) -> bool
pub fn set_mProvidesDefaultRoute(&mut self, val: bool)
pub unsafe fn mProvidesDefaultRoute_raw(this: *const Self) -> bool
pub unsafe fn set_mProvidesDefaultRoute_raw(this: *mut Self, val: bool)
pub fn mManagedAddressConfigFlag(&self) -> bool
pub fn set_mManagedAddressConfigFlag(&mut self, val: bool)
pub unsafe fn mManagedAddressConfigFlag_raw(this: *const Self) -> bool
pub unsafe fn set_mManagedAddressConfigFlag_raw(this: *mut Self, val: bool)
pub fn mOtherConfigFlag(&self) -> bool
pub fn set_mOtherConfigFlag(&mut self, val: bool)
pub unsafe fn mOtherConfigFlag_raw(this: *const Self) -> bool
pub unsafe fn set_mOtherConfigFlag_raw(this: *mut Self, val: bool)
pub fn mSnacRouterFlag(&self) -> bool
pub fn set_mSnacRouterFlag(&mut self, val: bool)
pub unsafe fn mSnacRouterFlag_raw(this: *const Self) -> bool
pub unsafe fn set_mSnacRouterFlag_raw(this: *mut Self, val: bool)
pub fn mIsLocalDevice(&self) -> bool
pub fn set_mIsLocalDevice(&mut self, val: bool)
pub unsafe fn mIsLocalDevice_raw(this: *const Self) -> bool
pub unsafe fn set_mIsLocalDevice_raw(this: *mut Self, val: bool)
pub fn mIsReachable(&self) -> bool
pub fn set_mIsReachable(&mut self, val: bool)
pub unsafe fn mIsReachable_raw(this: *const Self) -> bool
pub unsafe fn set_mIsReachable_raw(this: *mut Self, val: bool)
pub fn mIsPeerBr(&self) -> bool
pub fn set_mIsPeerBr(&mut self, val: bool)
pub unsafe fn mIsPeerBr_raw(this: *const Self) -> bool
pub unsafe fn set_mIsPeerBr_raw(this: *mut Self, val: bool)
pub fn new_bitfield_1( mProvidesDefaultRoute: bool, mManagedAddressConfigFlag: bool, mOtherConfigFlag: bool, mSnacRouterFlag: bool, mIsLocalDevice: bool, mIsReachable: bool, mIsPeerBr: bool, ) -> __BindgenBitfieldUnit<[u8; 1]>