#[repr(C)]pub struct otHistoryTrackerMessageInfo {
pub mPayloadLength: u16,
pub mNeighborRloc16: u16,
pub mSource: otSockAddr,
pub mDestination: otSockAddr,
pub mChecksum: u16,
pub mIpProto: u8,
pub mIcmp6Type: u8,
pub mAveRxRss: i8,
pub _bitfield_align_1: [u8; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 1]>,
}Expand description
Represents a RX/TX IPv6 message info.
Some of the fields in this struct are applicable to a RX message or a TX message only, e.g., mAveRxRss is the
average RSS of all fragment frames that form a received message and is only applicable for a RX message.
Fields
mPayloadLength: u16< IPv6 payload length (exclude IP6 header itself).
mNeighborRloc16: u16< RLOC16 of neighbor which sent/received the msg (0xfffe if no RLOC16).
mSource: otSockAddr< Source IPv6 address and port (if UDP/TCP)
mDestination: otSockAddr< Destination IPv6 address and port (if UDP/TCP).
mChecksum: u16< Message checksum (valid only for UDP/TCP/ICMP6).
mIpProto: u8< IP Protocol number (OT_IP6_PROTO_* enumeration).
mIcmp6Type: u8< ICMP6 type if msg is ICMP6, zero otherwise (OT_ICMP6_TYPE_* enumeration).
mAveRxRss: i8< RSS of received message or OT_RADIO_INVALID_RSSI if not known.
_bitfield_align_1: [u8; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 1]>Implementations
Sourceimpl otHistoryTrackerMessageInfo
impl otHistoryTrackerMessageInfo
pub fn mLinkSecurity(&self) -> bool
pub fn set_mLinkSecurity(&mut self, val: bool)
pub unsafe fn mLinkSecurity_raw(this: *const Self) -> bool
pub unsafe fn set_mLinkSecurity_raw(this: *mut Self, val: bool)
pub fn mTxSuccess(&self) -> bool
pub fn set_mTxSuccess(&mut self, val: bool)
pub unsafe fn mTxSuccess_raw(this: *const Self) -> bool
pub unsafe fn set_mTxSuccess_raw(this: *mut Self, val: bool)
pub fn mPriority(&self) -> u8
pub fn set_mPriority(&mut self, val: u8)
pub unsafe fn mPriority_raw(this: *const Self) -> u8
pub unsafe fn set_mPriority_raw(this: *mut Self, val: u8)
pub fn mRadioIeee802154(&self) -> bool
pub fn set_mRadioIeee802154(&mut self, val: bool)
pub unsafe fn mRadioIeee802154_raw(this: *const Self) -> bool
pub unsafe fn set_mRadioIeee802154_raw(this: *mut Self, val: bool)
pub fn mRadioTrelUdp6(&self) -> bool
pub fn set_mRadioTrelUdp6(&mut self, val: bool)
pub unsafe fn mRadioTrelUdp6_raw(this: *const Self) -> bool
pub unsafe fn set_mRadioTrelUdp6_raw(this: *mut Self, val: bool)
pub fn new_bitfield_1( mLinkSecurity: bool, mTxSuccess: bool, mPriority: u8, mRadioIeee802154: bool, mRadioTrelUdp6: bool, ) -> __BindgenBitfieldUnit<[u8; 1]>