Type Alias otCliConsoleOutputCallback

pub type otCliConsoleOutputCallback = Option<unsafe extern "C" fn(aBuf: *const c_char, aBufLength: u16, aContext: *mut c_void) -> c_int>;
This function pointer is called to notify about Console output.

@param[in] aBuf A pointer to a buffer with an output. @param[in] aBufLength A length of the output data stored in the buffer. @param[out] aContext A user context pointer.

@returns Number of bytes processed by the callback.

Aliased Type

enum otCliConsoleOutputCallback {
    None,
    Some(unsafe extern "C" fn(_: *const i8, _: u16, _: *mut c_void) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(_: *const i8, _: u16, _: *mut c_void) -> i32)

Some value of type T.