pub type otHistoryTrackerNetInfoCallback = Option<unsafe extern "C" fn(aError: otError, aNetworkInfo: *const otHistoryTrackerNetworkInfo, aEntryAge: u32, aContext: *mut c_void)>;Expand description
Callback function pointer type to report the retrieved Network Info entries from a query to another device.
Used when OPENTHREAD_CONFIG_HISTORY_TRACKER_CLIENT_ENABLE is enabled.
@param[in] aError Indicates the status of the query and entries being reported:
- OT_ERROR_PENDING: There are more entries to be reported.
- OT_ERROR_NONE: This is the last entry, and the query is complete.
- OT_ERROR_RESPONSE_TIMEOUT: Timed out waiting for a response.
- OT_ERROR_PARSE: The received query answer does not follow the expected format.
@param[in] aNetworkInfo The network information entry. This may be NULL if aError is OT_ERROR_NONE
(indicating the end of the list) or on certain error conditions.
@param[in] aEntryAge The entry age in milliseconds. Applicable only when @p aNetworkInfo is not NULL.
@param[in] aContext An arbitrary callback context provided by the caller during the query.
Aliased Type
pub enum otHistoryTrackerNetInfoCallback {
None,
Some(unsafe extern "C" fn(u32, *const otHistoryTrackerNetworkInfo, u32, *mut c_void)),
}