pub type otUdpReceive = Option<unsafe extern "C" fn(aContext: *mut c_void, aMessage: *mut otMessage, aMessageInfo: *const otMessageInfo)>;Expand description
Callback function pointer to notify the application of a received UDP message on a UDP socket.
This callback does not transfer ownership of @p aMessage. The callback implementation must not modify the message content. The message is guaranteed to be valid only within the context of the callback.
@param[in] aContext A pointer to the application-specific context. @param[in] aMessage A pointer to the received UDP message. @param[in] aMessageInfo A pointer to the IPv6 message info structure.
Aliased Type
pub enum otUdpReceive {
None,
Some(unsafe extern "C" fn(*mut c_void, *mut otMessage, *const otMessageInfo)),
}